/*
 * AVISA software - $Id: AsciiRecord.java,v 1.3 2006/03/13 13:32:43 marcoz Exp $
 *
 * Copyright (C) 2005 by EUMETSAT
 *
 * The Licensee acknowledges that the AVISA software is owned by the European
 * Organisation for the Exploitation of Meteorological Satellites
 * (EUMETSAT) and the Licensee shall not transfer, assign, sub-licence,
 * reproduce or copy the AVISA software to any third party or part with
 * possession of this software or any part thereof in any way whatsoever.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.
 * The AVISA software has been developed using the ESA BEAM software which is
 * distributed under the GNU General Public License (GPL).
 *
 */
package org.eumetsat.beam.dataio.metop;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.imageio.stream.ImageInputStream;

import org.esa.beam.framework.datamodel.MetadataElement;

/**
 * The abstarct base class for all header containing infomation in ASCII format
 *
 * @author marcoz
 * @version $Revision: 1.3 $ $Date: 2006/03/13 13:32:43 $
 */
abstract class AsciiRecord {
	
	private Map map;
	private int numFields;

	public AsciiRecord(int numFields) {
		this.numFields = numFields;
		map = new HashMap();
	}

	public void readRecord(ImageInputStream imageInputStream) throws IOException {
		for(int i=0; i < numFields; i++) {
			String fieldString = imageInputStream.readLine();
			KeyValuePair field = new KeyValuePair(fieldString);
			map.put(field.key, field.value);
		}
	}
	
	public String getValue(String key) {
		return (String) map.get(key);
	}
	
	public int getIntValue(String key) {
		return Integer.parseInt(getValue(key));
	}

	public long getLongValue(String key) {
		return Long.parseLong(getValue(key));
	}
	
	abstract public MetadataElement getMetaData();
	
	private class KeyValuePair {
		String key;
		String value;
		
		public KeyValuePair(String field) {
			key = field.substring(0, 30).trim();
			value = field.substring(32).trim();
			
			System.out.println(field);
		}
	}
	
	void printValues() {
		List keys = new ArrayList(map.keySet());
		Collections.sort(keys);
		
		
		for (Iterator iter = keys.iterator(); iter.hasNext();) {
			String key = (String) iter.next();
			System.out.println(key + "=" + map.get(key));
		}
	}
}